@@ -4,7 +4,7 @@
 # @return list with options including default for missing options
 
 add_missing_options <- function(opts, host = "api.globalbioticinteractions.org") {
-  defaults <- list(host = host, port = 80)
+  defaults <- list(host = host, port = 443)
   opts <- c(opts, defaults)
   opts[unique(names(opts))]
 }
@@ -16,7 +16,7 @@ add_missing_options <- function(opts, host = "api.globalbioticinteractions.org")
 # @return url address used to call api
 get_globi_url <- function(suffix, opts = list()) {
   opts <- add_missing_options(opts)
-  paste("http://", opts$host, ":", opts$port, suffix, sep = "")
+  paste("https://", opts$host, ":", opts$port, suffix, sep = "")
 }
 
 # Read csv URL
@@ -27,7 +27,7 @@ read_csv <- function(url, ...) {
 
 #' Get Species Interaction from GloBI
 #'
-#' @param taxon canonical scientic name of source taxon (e.g. Homo sapiens)
+#' @param taxon canonical scientific name of source taxon (e.g. Homo sapiens)
 #' @param interaction.type the preferred interaction type (e.g. preysOn)
 #' @param ... list of options to configure GloBI API
 #' @return species interactions between source and target taxa
