@@ -47,7 +47,7 @@ test_that("interactions subsetted by adding additional information", {
   expect_equal(class(rattus$source_taxon_name), "character")
   expect_true(dim(rattus)[1] > 0)
   expect_lt(dim(rattusaves)[1], dim(rattus)[1])
-  expect_equal(dim(merge(rattusaves,rattus, all.x=T, all.y=T)), dim(rattus))
+  expect_equal(dim(unique(rbind(rattusaves,rattus))), dim(unique(rattus)))
 })
 
 test_that("interactions subsetted by adding additional information all interaction types", {
@@ -57,7 +57,7 @@ test_that("interactions subsetted by adding additional information all interacti
   expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   # note that some interaction types (e.g. interactsWith) are symmetric
   # if a specific source (e.g. Thessen et al. 2014) reported a -[:INTERACTS_WITH]-> b and (a separate entry) b -[:INTERACTS_WITH]-> a, then both show up when looking for interactions between a and b, because the inverse of interactsWith is interactsWith.
-  expect_equal(dim(merge(rattusaves,rattus, all.x=T, all.y=T)), dim(rattus))
+  expect_equal(dim(unique(rbind(rattusaves,rattus))), dim(unique(rattus)))
 })
 
 test_that("interactions subsetted by adding additional information all interaction types include observations", {
@@ -67,7 +67,7 @@ test_that("interactions subsetted by adding additional information all interacti
   expect_lt(dim(rattusaves)[1], dim(rattus)[1])
   # note that some interaction types (e.g. interactsWith) are symmetric
   # if a specific source (e.g. Thessen et al. 2014) reported a -[:INTERACTS_WITH]-> b and (a separate entry) b -[:INTERACTS_WITH]-> a, then both show up when looking for interactions between a and b, because the inverse of interactsWith is interactsWith.
-  expect_equal(dim(merge(unique(rattusaves),unique(rattus), all.x=T, all.y=T)), dim(unique(rattus)))
+  expect_equal(dim(unique(rbind(rattusaves,rattus))), dim(unique(rattus)))
 })
 
 test_that("interactions subsetted by adding additional information using otherkeys, all interaction types include observations", {
